@@ -16,12 +16,11 @@
 # You should have received a copy of the GNU General Public License
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
-from .changelog import ChangelogError, add_skeleton, update
-from .conventional_commits import ChangelogBuilder, ChangelogBuilderError, main
+from .conventional_commits import ChangelogBuilder
+from .errors import ChangelogBuilderError, ChangelogError
+from .main import main
 
 __all__ = [
-    "add_skeleton",
-    "update",
     "ChangelogError",
     "ChangelogBuilder",
     "ChangelogBuilderError",
