@@ -21,8 +21,10 @@ from os import PathLike, fspath
 from pathlib import Path
 from typing import List, Optional, Union
 
+from pontos.errors import PontosError
 
-class GitError(subprocess.CalledProcessError):
+
+class GitError(subprocess.CalledProcessError, PontosError):
     """
     Error raised while executing a git command
     """
@@ -60,10 +62,15 @@ def exec_git(
     try:
         cmd_args = ["git"]
         cmd_args.extend(args)
-        output = subprocess.check_output(
-            cmd_args, cwd=fspath(cwd) if cwd else None
+        output = subprocess.run(
+            cmd_args,
+            cwd=fspath(cwd) if cwd else None,
+            check=True,
+            stdout=subprocess.PIPE,
+            encoding="utf8",
+            errors="replace",
         )
-        return output.decode()
+        return output.stdout
     except subprocess.CalledProcessError as e:
         if ignore_errors:
             return ""
@@ -119,6 +126,9 @@ class Git:
         """
         self._cwd = cwd.absolute()
 
+    def exec(self, *args: str) -> str:
+        return exec_git(*args, cwd=self._cwd)
+
     def init(self, *, bare: Optional[bool] = False) -> None:
         """
         Init a git repository
@@ -130,7 +140,8 @@ class Git:
         args = ["init"]
         if bare:
             args.append("--bare")
-        exec_git(*args, cwd=self._cwd)
+
+        self.exec(*args)
 
     def create_branch(
         self, branch: str, *, start_point: Optional[str] = None
@@ -147,7 +158,7 @@ class Git:
         if start_point:
             args.append(start_point)
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def rebase(
         self,
@@ -183,7 +194,7 @@ class Git:
         if head:
             args.append(head)
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def clone(
         self,
@@ -212,10 +223,7 @@ class Git:
             args.extend(["--depth", str(depth)])
         args.extend([repo_url, str(destination.absolute())])
 
-        exec_git(
-            *args,
-            cwd=self._cwd,
-        )
+        self.exec(*args)
 
     def push(
         self,
@@ -246,7 +254,7 @@ class Git:
             if branch:
                 args.append(branch)
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def config(
         self,
@@ -272,7 +280,7 @@ class Git:
         if value is not None:
             args.append(value)
 
-        return exec_git(*args, cwd=self._cwd)
+        return self.exec(*args)
 
     def cherry_pick(self, commits: Union[str, List[str]]) -> None:
         """
@@ -288,7 +296,7 @@ class Git:
         args = ["cherry-pick"]
         args.extend(commits)
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def list_tags(self, *, sort: Optional[TagSort] = None) -> List[str]:
         """
@@ -297,7 +305,8 @@ class Git:
         args = ["tag", "-l"]
         if sort:
             args.append(f"--sort={sort.value}")
-        return exec_git(*args, cwd=self._cwd).splitlines()
+
+        return self.exec(*args).splitlines()
 
     def add(self, files: Union[PathLike, List[PathLike]]) -> None:
         """
@@ -312,7 +321,7 @@ class Git:
         args = ["add"]
         args.extend([fspath(file) for file in files])
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def commit(
         self,
@@ -337,7 +346,7 @@ class Git:
 
         args.extend(["-m", message])
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def tag(
         self,
@@ -369,7 +378,7 @@ class Git:
 
         args.append(tag)
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def fetch(
         self,
@@ -397,7 +406,7 @@ class Git:
         if verbose:
             args.append("-v")
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def add_remote(self, remote: str, url: str) -> None:
         """
@@ -410,7 +419,7 @@ class Git:
 
         args = ["remote", "add", remote, url]
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def remote_url(self, remote: str = "origin") -> str:
         """
@@ -420,7 +429,7 @@ class Git:
             remote: Name of the remote. Default: origin.
         """
         args = ["remote", "get-url", remote]
-        return exec_git(*args, cwd=self._cwd)
+        return self.exec(*args)
 
     def checkout(
         self, branch: str, *, start_point: Optional[str] = None
@@ -439,7 +448,7 @@ class Git:
         else:
             args = ["checkout", branch]
 
-        exec_git(*args, cwd=self._cwd)
+        self.exec(*args)
 
     def log(self, *log_args: str, oneline: Optional[bool] = None) -> List[str]:
         """
@@ -453,4 +462,42 @@ class Git:
 
         args.extend(log_args)
 
-        return exec_git(*args, cwd=self._cwd).splitlines()
+        return self.exec(*args).splitlines()
+
+    def rev_list(
+        self,
+        *commit: str,
+        max_parents: Optional[int] = None,
+        abbrev_commit: Optional[bool] = False,
+    ) -> List[str]:
+        """
+        Lists commit objects in reverse chronological order
+
+        Args:
+            commit: commit objects.
+            max_parents: Only list nth oldest commits
+            abbrev_commit: Set to True to show  prefix that names the commit
+                object uniquely instead of the full commit ID.
+
+        Examples:
+            .. code-block:: python
+
+            git = Git()
+            git.rev_list("foo", "bar", "^baz")
+
+            This will "list all the commits which are reachable from foo or bar,
+            but not from baz".
+
+            git = Git()
+            git.rev_list("foo", max_parents=0)
+
+            This will return the first commit of foo.
+        """
+        args = ["rev-list"]
+        if max_parents is not None:
+            args.append(f"--max-parents={max_parents}")
+        if abbrev_commit:
+            args.append("--abbrev-commit")
+
+        args.extend(commit)
+        return self.exec(*args).splitlines()
