@@ -17,11 +17,8 @@
 
 from typing import AsyncIterator, Iterable, Optional, Union
 
-import httpx
-
 from pontos.github.api.client import GitHubAsyncREST
 from pontos.github.api.errors import GitHubApiError
-from pontos.github.api.helper import JSON
 from pontos.github.models.base import User
 from pontos.github.models.organization import (
     InvitationRole,
@@ -226,72 +223,3 @@ class GitHubAsyncRESTOrganizations(GitHubAsyncREST):
         api = f"/orgs/{organization}/outside_collaborators/{username}"
         response = await self._client.delete(api)
         response.raise_for_status()
-
-
-class GitHubRESTOrganizationsMixin:
-    def organisation_exists(self, orga: str) -> bool:
-        """
-        Check if an organization exists
-
-        Args:
-            repo: GitHub repository (owner/name) to use
-        """
-        api = f"/orgs/{orga}"
-        response: httpx.Response = self._request(api)
-        return response.is_success
-
-    def get_organization_repository_number(
-        self, orga: str, repository_type: RepositoryType
-    ) -> int:
-        """
-        Get total number of repositories of organization
-
-        Args:
-            repo: GitHub repository (owner/name) to use
-            pull_request: Pull request number to check
-        """
-        api = f"/orgs/{orga}"
-        response: httpx.Response = self._request(api)
-        response.raise_for_status()
-        response_json = response.json()
-
-        if repository_type == RepositoryType.PUBLIC:
-            return response_json["public_repos"]
-        if repository_type == RepositoryType.PRIVATE:
-            return response_json["total_private_repos"]
-            # Use ALL for currently unsupported "types" (INTERNAL, FORKS ...)
-        return (
-            response_json["public_repos"] + response_json["total_private_repos"]
-        )
-
-    def get_repositories(
-        self,
-        orga: str,
-        repository_type: RepositoryType = RepositoryType.ALL,
-    ) -> JSON:
-        """
-        Get information about organization repositories
-
-        Args:
-            orga: GitHub organization to use
-        """
-        api = f"/orgs/{orga}/repos"
-
-        count = self.get_organization_repository_number(
-            orga=orga, repository_type=repository_type
-        )
-        downloaded = 0
-
-        repos = []
-        params = {"type": repository_type.value, "per_page": 100}
-        page = 0
-        while count - downloaded > 0:
-            page += 1
-            params["page"] = page
-            response: httpx.Response = self._request(api, params=params)
-            response.raise_for_status()
-
-            repos.extend(response.json())
-            downloaded = len(repos)
-
-        return repos
