@@ -18,7 +18,6 @@
 
 import os
 import re
-import subprocess
 import sys
 import warnings
 from contextlib import asynccontextmanager, contextmanager
@@ -35,7 +34,6 @@ from typing import (
     Dict,
     Generator,
     Generic,
-    Iterable,
     Iterator,
     Optional,
     Tuple,
@@ -287,17 +285,6 @@ def download(
         )
 
 
-def shell_cmd_runner(args: Iterable[str]) -> subprocess.CompletedProcess:
-    return subprocess.run(
-        args,
-        shell=True,
-        check=True,
-        errors="utf-8",
-        stdout=subprocess.PIPE,
-        stderr=subprocess.PIPE,
-    )
-
-
 def deprecated(
     _func_or_cls: Union[str, Callable, Type] = None,
     *,
