@@ -18,34 +18,20 @@
 import sys
 from typing import NoReturn
 
-from pontos.version.helper import VersionError, initialize_default_parser
-from pontos.version.version import VersionCommand
+from pontos.errors import PontosError
+from pontos.version.commands import gather_project
 
 from .__version__ import __version__
-from .cmake import CMakeVersionCommand
-from .go import GoVersionCommand
-from .javascript import JavaScriptVersionCommand
-from .python import PythonVersionCommand
-
-COMMANDS = (
-    CMakeVersionCommand,
-    GoVersionCommand,
-    JavaScriptVersionCommand,
-    PythonVersionCommand,
-)
+from .errors import VersionError
+from .parser import initialize_default_parser
 
 
 def main() -> NoReturn:
     parser = initialize_default_parser()
 
-    found = False
-    for cmd in COMMANDS:
-        command: VersionCommand = cmd()  # type: ignore
-        if command.project_found():
-            found = True
-            break
-
-    if not found:
+    try:
+        command = gather_project()
+    except PontosError:
         print("No project found.", file=sys.stderr)
         sys.exit(1)
 
