@@ -16,15 +16,18 @@
 # along with this program.  If not, see <http://www.gnu.org/licenses/>.
 
 from abc import ABC, abstractmethod
-from dataclasses import dataclass
+from dataclasses import dataclass, field
 from pathlib import Path
-from typing import Optional
+from typing import Type
+
+from pontos.version.calculator import VersionCalculator
 
 
 @dataclass
-class UpdatedVersion:
+class VersionUpdate:
     previous: str
     new: str
+    changed_files: list[Path] = field(default_factory=list)
 
 
 class VersionCommand(ABC):
@@ -32,12 +35,10 @@ class VersionCommand(ABC):
     version commands for several programming languages"""
 
     project_file_name: str
+    version_calculator_class: Type[VersionCalculator] = VersionCalculator
 
-    def __init__(self, *, project_file_path: Optional[Path] = None) -> None:
-        if project_file_path:
-            self.project_file_path = project_file_path
-        else:
-            self.project_file_path = Path.cwd() / self.project_file_name
+    def __init__(self) -> None:
+        self.project_file_path = Path.cwd() / self.project_file_name
 
     @abstractmethod
     def get_current_version(self) -> str:
@@ -49,21 +50,15 @@ class VersionCommand(ABC):
 
     @abstractmethod
     def update_version(
-        self, new_version: str, *, develop: bool = False, force: bool = False
-    ) -> UpdatedVersion:
+        self, new_version: str, *, force: bool = False
+    ) -> VersionUpdate:
         """Update the current version of this project"""
 
-    def project_file_found(self) -> Optional[Path]:
-        """
-        Returns a path to the project file if a command has detected a
-        corresponding project
-        """
-        return (
-            self.project_file_path if self.project_file_path.exists() else None
-        )
-
     def project_found(self) -> bool:
         """
         Returns True if a command has detected a corresponding project
         """
-        return bool(self.project_file_found())
+        return self.project_file_path.exists()
+
+    def get_version_calculator(self) -> VersionCalculator:
+        return self.version_calculator_class()
