@@ -18,46 +18,51 @@
 
 import json
 import unittest
-from pathlib import Path
 from unittest.mock import MagicMock, patch
 
 from pontos.testing import temp_directory, temp_file
-from pontos.version.helper import VersionError
+from pontos.version.calculator import VersionCalculator
+from pontos.version.errors import VersionError
 from pontos.version.javascript import JavaScriptVersionCommand
 
 
+class JavaScriptVersionCommandTestCase(unittest.TestCase):
+    def test_get_version_calculator(self):
+        js = JavaScriptVersionCommand()
+
+        self.assertIsInstance(js.get_version_calculator(), VersionCalculator)
+
+
 class GetCurrentJavaScriptVersionCommandTestCase(unittest.TestCase):
     def test_get_current_version(self):
         content = '{"name": "foo", "version": "1.2.3"}'
-        with temp_file(content, name="package.json", change_into=True) as temp:
-            cmd = JavaScriptVersionCommand(project_file_path=temp)
+        with temp_file(content, name="package.json", change_into=True):
+            cmd = JavaScriptVersionCommand()
             version = cmd.get_current_version()
 
             self.assertEqual(version, "1.2.3")
 
     def test_no_project_file(self):
-        cmd = JavaScriptVersionCommand(project_file_path=Path("foo/bar/baz"))
-        with self.assertRaisesRegex(
-            VersionError, "foo/bar/baz file not found."
+        with temp_directory(change_into=True), self.assertRaisesRegex(
+            VersionError, ".* file not found."
         ):
+            cmd = JavaScriptVersionCommand()
             cmd.get_current_version()
 
     def test_no_package_version(self):
         content = '{"name": "foo"}'
         with temp_file(
             content, name="package.json", change_into=True
-        ) as temp, self.assertRaisesRegex(
-            VersionError, "Version field missing in"
-        ):
-            cmd = JavaScriptVersionCommand(project_file_path=temp)
+        ), self.assertRaisesRegex(VersionError, "Version field missing in"):
+            cmd = JavaScriptVersionCommand()
             cmd.get_current_version()
 
     def test_no_valid_json_in_package_version(self):
         content = "{"
         with temp_file(
             content, name="package.json", change_into=True
-        ) as temp, self.assertRaisesRegex(VersionError, "No valid JSON found."):
-            cmd = JavaScriptVersionCommand(project_file_path=temp)
+        ), self.assertRaisesRegex(VersionError, "No valid JSON found."):
+            cmd = JavaScriptVersionCommand()
             cmd.get_current_version()
 
 
@@ -66,48 +71,67 @@ class UpdateJavaScriptVersionCommandTestCase(unittest.TestCase):
         content = '{"name":"foo", "version":"1.2.3"}'
 
         with temp_file(content, name="package.json", change_into=True) as temp:
-            cmd = JavaScriptVersionCommand(project_file_path=temp)
+            cmd = JavaScriptVersionCommand()
             cmd.get_current_version()
             updated = cmd.update_version("22.4.0")
 
             self.assertEqual(updated.previous, "1.2.3")
             self.assertEqual(updated.new, "22.4.0")
+            self.assertEqual(updated.changed_files, [temp])
 
             with temp.open(mode="r", encoding="utf-8") as fp:
                 fake_package = json.load(fp)
 
             self.assertEqual(fake_package["version"], "22.4.0")
 
-    def test_update_version_check_develop(self):
-        content = '{"name":"foo", "version":"1.2.3"}'
-
-        with temp_file(content, name="package.json", change_into=True) as temp:
-            cmd = JavaScriptVersionCommand(project_file_path=temp)
-            updated = cmd.update_version("22.4.0.dev1", develop=True)
-
-            self.assertEqual(updated.previous, "1.2.3")
-            self.assertEqual(updated.new, "22.4.0.dev1")
-
-            with temp.open(mode="r", encoding="utf-8") as fp:
-                fake_package = json.load(fp)
-
-            self.assertEqual(fake_package["version"], "22.4.0.dev1")
-
     def test_update_version_develop(self):
         content = '{"name":"foo", "version":"1.2.3"}'
 
         with temp_file(content, name="package.json", change_into=True) as temp:
-            cmd = JavaScriptVersionCommand(project_file_path=temp)
-            updated = cmd.update_version("22.4.0", develop=True)
+            cmd = JavaScriptVersionCommand()
+            updated = cmd.update_version("22.4.0.dev1")
 
             self.assertEqual(updated.previous, "1.2.3")
             self.assertEqual(updated.new, "22.4.0.dev1")
+            self.assertEqual(updated.changed_files, [temp])
 
             with temp.open(mode="r", encoding="utf-8") as fp:
                 fake_package = json.load(fp)
 
             self.assertEqual(fake_package["version"], "22.4.0.dev1")
 
+    def test_no_update(self):
+        content = '{"name":"foo", "version":"1.2.3"}'
+
+        with temp_file(content, name="package.json", change_into=True) as temp:
+            cmd = JavaScriptVersionCommand()
+            updated = cmd.update_version("1.2.3")
+
+            self.assertEqual(updated.previous, "1.2.3")
+            self.assertEqual(updated.new, "1.2.3")
+            self.assertEqual(updated.changed_files, [])
+
+            with temp.open(mode="r", encoding="utf-8") as fp:
+                fake_package = json.load(fp)
+
+            self.assertEqual(fake_package["version"], "1.2.3")
+
+    def test_forced_update(self):
+        content = '{"name":"foo", "version":"1.2.3"}'
+
+        with temp_file(content, name="package.json", change_into=True) as temp:
+            cmd = JavaScriptVersionCommand()
+            updated = cmd.update_version("1.2.3", force=True)
+
+            self.assertEqual(updated.previous, "1.2.3")
+            self.assertEqual(updated.new, "1.2.3")
+            self.assertEqual(updated.changed_files, [temp])
+
+            with temp.open(mode="r", encoding="utf-8") as fp:
+                fake_package = json.load(fp)
+
+            self.assertEqual(fake_package["version"], "1.2.3")
+
 
 class VerifyJavaScriptVersionCommandTestCase(unittest.TestCase):
     def test_current_version_not_pep440_compliant(self):
@@ -145,16 +169,13 @@ class VerifyJavaScriptVersionCommandTestCase(unittest.TestCase):
 
 class ProjectFileJavaScriptVersionCommandTestCase(unittest.TestCase):
     def test_project_file_not_found(self):
-        with temp_directory() as temp:
-            package_json = temp / "package.json"
-            cmd = JavaScriptVersionCommand(project_file_path=package_json)
+        with temp_directory(change_into=True):
+            cmd = JavaScriptVersionCommand()
 
-            self.assertIsNone(cmd.project_file_found())
             self.assertFalse(cmd.project_found())
 
     def test_project_file_found(self):
-        with temp_file(name="package.json") as package_json:
-            cmd = JavaScriptVersionCommand(project_file_path=package_json)
+        with temp_file(name="package.json", change_into=True):
+            cmd = JavaScriptVersionCommand()
 
-            self.assertEqual(cmd.project_file_found(), package_json)
             self.assertTrue(cmd.project_found())
